//
//  TodoViewModel.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/5.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import RxSwift

class TodoViewModel: BaseViewModel {

    /// 查询待办事项model
    lazy final var queryModel: QueryTodoModel = {
        var queryModel = QueryTodoModel()
        queryModel.prompt = "未处理"
        queryModel.receiver = kUser().userUuid
        return queryModel
    }()
    
    /// 待办事项结果
    lazy final var todoArray: Array<Record> = {
       var todoArray = Array<Record>()
        return todoArray
    }()
    
    
    /// 查询待办事项
    ///
    /// - Parameters:
    ///   - page: 页数
    ///   - state: 状态
    func queryTodoAction(_ page: Int,_ state: TODO_STATE) ->Observable<Int> {
        queryModel.page = page
        queryModel.pageSize = kPageSize
        queryModel.state = state.rawValue
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .QueryTodo(self.queryModel), success: {[weak self] (json) in
                let resultModel = TodoResultModel(fromJson: json)
                if resultModel.success {
                    if page == kZERO {
                        self?.todoArray.removeAll()
                    }
                    for data in resultModel.data.records {
                        self?.todoArray.append(data)
                    }
                    observer.onNext(resultModel.data.paging.pageCount)
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
}

extension TodoViewModel {
    
    
    /// 待办事项菜单调用
    func dequeueReusableCell(_ identifier: String, _ indexPath: IndexPath, _ tableView: UITableView) -> UITableViewCell {
        let todoCell = tableView.dequeueReusableCell(withIdentifier: identifier, for: indexPath) as! TodoTableViewCell
        return todoCell
    }
    
    /// 首页待办事项调用
    func dequeueReusableHomeCell(_ identifier: String, _ indexPath: IndexPath, _ tableView: UITableView) -> UITableViewCell {
        let todoCell = tableView.dequeueReusableCell(withIdentifier: identifier, for: indexPath) as! HomeTableViewCell
        return todoCell
    }
}





